% BEGIN FILE: eulerline.m
% 23-Aug-2018 11:00:14
% Plots Euler line of a triangle with vertices a,b,c
% It goes through circumcenter m, (a+b+c)/3, orthocenter
help eulerline
clear; close all;
a=(0.4+rand)+1i*rand;
b=-(0.3+rand)+1i*rand;
c=-(0.2+rand)-1i*(0.4+rand);
hold on
plot(real([a,b,c,a]),imag([a,b,c,a]),'LineWidth',2)
%midpoints of sides opposite to a,b,c:
ma=(b+c)/2; mb=(a+c)/2;  mc=(b+a)/2;
plot(real([a,ma]),imag([a,ma]),'k-', real([b,mb]),imag([b,mb]),'k-',...
    real([c,mc]),imag([c,mc]),'k-')
% m is center of circle through a,b,c (the radius is abs(m-a)  )
m=((b-c)*abs(a)^2 + (c-a)*abs(b)^2 + (a-b)*abs(c)^2)/...
    ((b-c)*conj(a) + (c-a)*conj(b) + (a-b)*conj(c));
plot(real([m,ma]),imag([m,ma]),'r-', real([m,mb]),imag([m,mb]),'r-',...
    real([m,mc]),imag([m,mc]),'r-')
% myreflect(z,a,b) gives the reflection of z in the line L(a,b) through a,b
myreflect=@(z,a,b)( ((a-b)/conj(a-b))*conj(z)- (a*conj(b)-conj(a)*b)/(conj(a-b)) );
% If w=myreflect(z,a,b), then trivially, the projection of 
% z on L(a,b) is (z+w)/2
% Projection of a on L(b,c) is basea
basea=(a+myreflect(a,b,c))/2; 
baseb=(b+myreflect(b,a,c))/2;
basec=(c+myreflect(c,b,a))/2;
plot(real([a,basea]),imag([a,basea]),'g-', real([b,baseb]),imag([b,baseb]),'g-',...
    real([c,basec]),imag([c,basec]),'g-')
% Intersection of L(a,b) and L(c,d) is LIS(a,b,c,d)
LIS=@(a,b,c,d)((c-d)*(-a*conj(b)+conj(a)*b)- (a-b)*(-c*conj(d)+conj(c)*d))/...
    ((c-d)*conj(a-b) - (a-b)*conj(c-d) );
pt1=LIS(a,basea, b, baseb); % Intersection of two "heights" of triangle a,b,c
% pt1 is orthocenter; by Euler's theorem pt1=a+b+c-2m
plot(real([pt1,m]), imag([pt1,m]), 'k-', 'LineWidth', 1.5);
plot(real([pt1,m,(a+b+c)/3]), imag([pt1,m, (a+b+c)/3]), 'k.','MarkerSize',20)
xlabel('Euler line','FontSize', 20,'FontWeight','Bold')
axis('equal')
r=abs(m-a);
the=0:(0.02*pi):2*pi; z=m+r*exp(i*the);
plot(real(z),imag(z),'k-')
%  By Euler's theorem orthocenter=a+b+c-2m
ortho=((b+c-a)*(b-c)*conj(a) +(a+c-b)* (c-a)*conj(b) + (b+a-c)*(a-b)*conj(c))/...
    ((b-c)*conj(a) + (c-a)*conj(b) + (a-b)*conj(c));
fprintf('Orthocenter formula test= %12.4e\n',abs(ortho-pt1))      % Check agreement with pt1
%endpoint of angle a bisector on side [b,c]
% bia=b+abs(a-b)*(c-b)/(abs(a-c)+ abs(a-b));
% bib=c+abs(b-c)*(a-c)/(abs(b-c)+ abs(a-b));
% bic=a+abs(a-c)*(b-a)/(abs(a-c)+ abs(c-b));
% plot(real([a,bia]),imag([a,bia]),'g-', real([b,bib]),imag([b,bib]),'g-',...
%    real([c,bic]),imag([c,bic]),'g-')
% END FILE: eulerline.m
