function varargout = julia_gui(varargin)
% The Julia set is illustrated through colorful plots. The user may 
% modify the complex parameter c of the function, as well as various 
% visualization options to create new images.
%
% The Julia set of a complex function h(z) = z^2 + c is the boundary 
% of the set of points whose orbits escape to infinity under the 
% iteration of the map z_n+1 = h(z).
% Example: The unit circle |z| = 1 is the Julia set of the function 
% h(z) = z^2. 
%
% Start the GUI with julia_gui from the MATLAB prompt.

% Last Modified by GUIDE v2.0 09-Dec-2002 18:12:48

% Author : Andreas Klimke, Stuttgart University
% Version: 1.1
% Date   : May 3, 2003
	
if nargin == 0  % LAUNCH GUI

	fig = openfig(mfilename,'reuse');

	% Use system color scheme for figure:
	set(fig,'Color',get(0,'defaultUicontrolBackgroundColor'));

	% Generate a structure of handles to pass to callbacks, and store it. 
	handles = guihandles(fig);
	guidata(fig, handles);
	set(handles.cmap,'Value',10);
	set(fig,'Units','pixels');

    guiviewsize = get(fig,'Position');
    screensize = get(0,'ScreenSize');
    screensize = screensize(3:4);
    viewsize = [400 300];
    viewoffset = [50 200];
    set(fig,'Position', [screensize(1)-viewsize(1)- ...
										2*viewoffset(1)-guiviewsize(3), screensize(2)- ...
										viewoffset(2)-guiviewsize(4), ...
										guiviewsize(3:4)]);
	pushbutton1_Callback([],[],handles);
	set(gcf,'Position',[screensize(1)-viewoffset(1)-viewsize(1), ...
            screensize(2)-viewoffset(2)-viewsize(2), viewsize])

	if nargout > 0
		varargout{1} = fig;
	end

elseif ischar(varargin{1}) % INVOKE NAMED SUBFUNCTION OR CALLBACK

	try
		[varargout{1:nargout}] = feval(varargin{:}); % FEVAL switchyard
	catch
		disp(lasterr);
	end

end

% --------------------------------------------------------------------
function varargout = edit1_Callback(h, eventdata, handles, varargin)
return;
	
% --------------------------------------------------------------------
function varargout = popupmenu1_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.popupmenu1.
s = get(handles.cmap,'String');
colormap(s{get(handles.cmap,'Value')});

% --------------------------------------------------------------------
function varargout = pushbutton2_Callback(h, eventdata, handles, varargin)
helpwin('julia_gui.m');

% --------------------------------------------------------------------
function varargout = pushbutton1_Callback(h, eventdata, handles, varargin)
s = get(handles.cmap,'String');
colormap(s{get(handles.cmap,'Value')});
re = str2double(get(handles.realpart,'String'));
im = str2double(get(handles.imaginarypart,'String'));
resolution = str2double(get(handles.resolution,'String'));
iter = str2double(get(handles.iter,'String'));
escape = str2double(get(handles.escape,'String'));
zoom = str2double(get(handles.zoom,'String'));
dx = str2double(get(handles.dx,'String'));
dy = str2double(get(handles.dy,'String'));
julia(re, im, resolution, escape, iter, dx, dy, zoom);