% FILE myfindiftst.m begins.
% Finite diff. approx of f'(x) is (f(x+h)-f(x))/h, error h|f"(xi)|
% Two types of errors: A. Truncation error B. Rounding error
% Total error = A + B
% A. Truncation error < M h where M is bound for |f"(x)|
% B. Rounding error <   w/h where   w machine epsilon
% Total error <  M h + w/h minimized when h =sqrt(w/M)
help myfindiftst
path(path,'../util')
startup
clear; close all;
w=10^(-16);  % Approximate value of machine precision
x0=0.9;
p=5:60;      % h= 2^(-p) 
dyerr=cos(x0)-((sin(x0+2.^(-p))-sin(x0))./(2.^(-p)));
% dyerr is exact derivative - finite difference approx der.
plot(p,log10(abs(dyerr)),'k-','LineWidth',2)
hold on
plot(p,log10(2.^(-p)+ (10^(-16))* 2.^p),'r-','LineWidth',1.5)
[mi,ind]=min(log(abs(dyerr)));
%disp(2.^(-p(ind)))   % Best choice of h
fprintf(' %2d   %16.4e   %12.2e\n',[(5:5:60)'  2.^(-(5:5:60)')   (abs(dyerr(1:5:end)))']')
title('Error in finite difference approxim, h= 2^{-p}')
xlabel(['Best accuracy for p= ' num2str(p(ind)) ', h = ' num2str(2^(-p(ind)), '%10.2e')])
ylabel('log10(abs(error))')
text(10,3,'Red  is theoretical error')
grid 
% FILE myfindiftst.m ends.
